**Author:** [Behrouz Safari](https://behrouzz.github.io/)<br/>
**License:** [MIT](https://opensource.org/licenses/MIT)<br/>

# solsys
*A python package for Solar System calculations*


## Installation

Install the latest version of *solsys* from [PyPI](https://pypi.org/project/solsys/):

    pip install solsys

Requirements: numpy, scipy, pandas, matplotlib, requests, jplephem, hypatie


See more at [astrodatascience.net](https://astrodatascience.net/)
